[−][src]Enum unicode_types::nushu::Nushu
An enum to represent all characters in the Nushu block.
Variants
CharacterDash1b170\u{1b170}: '𛅰'
CharacterDash1b171\u{1b171}: '𛅱'
CharacterDash1b172\u{1b172}: '𛅲'
CharacterDash1b173\u{1b173}: '𛅳'
CharacterDash1b174\u{1b174}: '𛅴'
CharacterDash1b175\u{1b175}: '𛅵'
CharacterDash1b176\u{1b176}: '𛅶'
CharacterDash1b177\u{1b177}: '𛅷'
CharacterDash1b178\u{1b178}: '𛅸'
CharacterDash1b179\u{1b179}: '𛅹'
CharacterDash1b17a\u{1b17a}: '𛅺'
CharacterDash1b17b\u{1b17b}: '𛅻'
CharacterDash1b17c\u{1b17c}: '𛅼'
CharacterDash1b17d\u{1b17d}: '𛅽'
CharacterDash1b17e\u{1b17e}: '𛅾'
CharacterDash1b17f\u{1b17f}: '𛅿'
CharacterDash1b180\u{1b180}: '𛆀'
CharacterDash1b181\u{1b181}: '𛆁'
CharacterDash1b182\u{1b182}: '𛆂'
CharacterDash1b183\u{1b183}: '𛆃'
CharacterDash1b184\u{1b184}: '𛆄'
CharacterDash1b185\u{1b185}: '𛆅'
CharacterDash1b186\u{1b186}: '𛆆'
CharacterDash1b187\u{1b187}: '𛆇'
CharacterDash1b188\u{1b188}: '𛆈'
CharacterDash1b189\u{1b189}: '𛆉'
CharacterDash1b18a\u{1b18a}: '𛆊'
CharacterDash1b18b\u{1b18b}: '𛆋'
CharacterDash1b18c\u{1b18c}: '𛆌'
CharacterDash1b18d\u{1b18d}: '𛆍'
CharacterDash1b18e\u{1b18e}: '𛆎'
CharacterDash1b18f\u{1b18f}: '𛆏'
CharacterDash1b190\u{1b190}: '𛆐'
CharacterDash1b191\u{1b191}: '𛆑'
CharacterDash1b192\u{1b192}: '𛆒'
CharacterDash1b193\u{1b193}: '𛆓'
CharacterDash1b194\u{1b194}: '𛆔'
CharacterDash1b195\u{1b195}: '𛆕'
CharacterDash1b196\u{1b196}: '𛆖'
CharacterDash1b197\u{1b197}: '𛆗'
CharacterDash1b198\u{1b198}: '𛆘'
CharacterDash1b199\u{1b199}: '𛆙'
CharacterDash1b19a\u{1b19a}: '𛆚'
CharacterDash1b19b\u{1b19b}: '𛆛'
CharacterDash1b19c\u{1b19c}: '𛆜'
CharacterDash1b19d\u{1b19d}: '𛆝'
CharacterDash1b19e\u{1b19e}: '𛆞'
CharacterDash1b19f\u{1b19f}: '𛆟'
CharacterDash1b1a0\u{1b1a0}: '𛆠'
CharacterDash1b1a1\u{1b1a1}: '𛆡'
CharacterDash1b1a2\u{1b1a2}: '𛆢'
CharacterDash1b1a3\u{1b1a3}: '𛆣'
CharacterDash1b1a4\u{1b1a4}: '𛆤'
CharacterDash1b1a5\u{1b1a5}: '𛆥'
CharacterDash1b1a6\u{1b1a6}: '𛆦'
CharacterDash1b1a7\u{1b1a7}: '𛆧'
CharacterDash1b1a8\u{1b1a8}: '𛆨'
CharacterDash1b1a9\u{1b1a9}: '𛆩'
CharacterDash1b1aa\u{1b1aa}: '𛆪'
CharacterDash1b1ab\u{1b1ab}: '𛆫'
CharacterDash1b1ac\u{1b1ac}: '𛆬'
CharacterDash1b1ad\u{1b1ad}: '𛆭'
CharacterDash1b1ae\u{1b1ae}: '𛆮'
CharacterDash1b1af\u{1b1af}: '𛆯'
CharacterDash1b1b0\u{1b1b0}: '𛆰'
CharacterDash1b1b1\u{1b1b1}: '𛆱'
CharacterDash1b1b2\u{1b1b2}: '𛆲'
CharacterDash1b1b3\u{1b1b3}: '𛆳'
CharacterDash1b1b4\u{1b1b4}: '𛆴'
CharacterDash1b1b5\u{1b1b5}: '𛆵'
CharacterDash1b1b6\u{1b1b6}: '𛆶'
CharacterDash1b1b7\u{1b1b7}: '𛆷'
CharacterDash1b1b8\u{1b1b8}: '𛆸'
CharacterDash1b1b9\u{1b1b9}: '𛆹'
CharacterDash1b1ba\u{1b1ba}: '𛆺'
CharacterDash1b1bb\u{1b1bb}: '𛆻'
CharacterDash1b1bc\u{1b1bc}: '𛆼'
CharacterDash1b1bd\u{1b1bd}: '𛆽'
CharacterDash1b1be\u{1b1be}: '𛆾'
CharacterDash1b1bf\u{1b1bf}: '𛆿'
CharacterDash1b1c0\u{1b1c0}: '𛇀'
CharacterDash1b1c1\u{1b1c1}: '𛇁'
CharacterDash1b1c2\u{1b1c2}: '𛇂'
CharacterDash1b1c3\u{1b1c3}: '𛇃'
CharacterDash1b1c4\u{1b1c4}: '𛇄'
CharacterDash1b1c5\u{1b1c5}: '𛇅'
CharacterDash1b1c6\u{1b1c6}: '𛇆'
CharacterDash1b1c7\u{1b1c7}: '𛇇'
CharacterDash1b1c8\u{1b1c8}: '𛇈'
CharacterDash1b1c9\u{1b1c9}: '𛇉'
CharacterDash1b1ca\u{1b1ca}: '𛇊'
CharacterDash1b1cb\u{1b1cb}: '𛇋'
CharacterDash1b1cc\u{1b1cc}: '𛇌'
CharacterDash1b1cd\u{1b1cd}: '𛇍'
CharacterDash1b1ce\u{1b1ce}: '𛇎'
CharacterDash1b1cf\u{1b1cf}: '𛇏'
CharacterDash1b1d0\u{1b1d0}: '𛇐'
CharacterDash1b1d1\u{1b1d1}: '𛇑'
CharacterDash1b1d2\u{1b1d2}: '𛇒'
CharacterDash1b1d3\u{1b1d3}: '𛇓'
CharacterDash1b1d4\u{1b1d4}: '𛇔'
CharacterDash1b1d5\u{1b1d5}: '𛇕'
CharacterDash1b1d6\u{1b1d6}: '𛇖'
CharacterDash1b1d7\u{1b1d7}: '𛇗'
CharacterDash1b1d8\u{1b1d8}: '𛇘'
CharacterDash1b1d9\u{1b1d9}: '𛇙'
CharacterDash1b1da\u{1b1da}: '𛇚'
CharacterDash1b1db\u{1b1db}: '𛇛'
CharacterDash1b1dc\u{1b1dc}: '𛇜'
CharacterDash1b1dd\u{1b1dd}: '𛇝'
CharacterDash1b1de\u{1b1de}: '𛇞'
CharacterDash1b1df\u{1b1df}: '𛇟'
CharacterDash1b1e0\u{1b1e0}: '𛇠'
CharacterDash1b1e1\u{1b1e1}: '𛇡'
CharacterDash1b1e2\u{1b1e2}: '𛇢'
CharacterDash1b1e3\u{1b1e3}: '𛇣'
CharacterDash1b1e4\u{1b1e4}: '𛇤'
CharacterDash1b1e5\u{1b1e5}: '𛇥'
CharacterDash1b1e6\u{1b1e6}: '𛇦'
CharacterDash1b1e7\u{1b1e7}: '𛇧'
CharacterDash1b1e8\u{1b1e8}: '𛇨'
CharacterDash1b1e9\u{1b1e9}: '𛇩'
CharacterDash1b1ea\u{1b1ea}: '𛇪'
CharacterDash1b1eb\u{1b1eb}: '𛇫'
CharacterDash1b1ec\u{1b1ec}: '𛇬'
CharacterDash1b1ed\u{1b1ed}: '𛇭'
CharacterDash1b1ee\u{1b1ee}: '𛇮'
CharacterDash1b1ef\u{1b1ef}: '𛇯'
CharacterDash1b1f0\u{1b1f0}: '𛇰'
CharacterDash1b1f1\u{1b1f1}: '𛇱'
CharacterDash1b1f2\u{1b1f2}: '𛇲'
CharacterDash1b1f3\u{1b1f3}: '𛇳'
CharacterDash1b1f4\u{1b1f4}: '𛇴'
CharacterDash1b1f5\u{1b1f5}: '𛇵'
CharacterDash1b1f6\u{1b1f6}: '𛇶'
CharacterDash1b1f7\u{1b1f7}: '𛇷'
CharacterDash1b1f8\u{1b1f8}: '𛇸'
CharacterDash1b1f9\u{1b1f9}: '𛇹'
CharacterDash1b1fa\u{1b1fa}: '𛇺'
CharacterDash1b1fb\u{1b1fb}: '𛇻'
CharacterDash1b1fc\u{1b1fc}: '𛇼'
CharacterDash1b1fd\u{1b1fd}: '𛇽'
CharacterDash1b1fe\u{1b1fe}: '𛇾'
CharacterDash1b1ff\u{1b1ff}: '𛇿'
CharacterDash1b200\u{1b200}: '𛈀'
CharacterDash1b201\u{1b201}: '𛈁'
CharacterDash1b202\u{1b202}: '𛈂'
CharacterDash1b203\u{1b203}: '𛈃'
CharacterDash1b204\u{1b204}: '𛈄'
CharacterDash1b205\u{1b205}: '𛈅'
CharacterDash1b206\u{1b206}: '𛈆'
CharacterDash1b207\u{1b207}: '𛈇'
CharacterDash1b208\u{1b208}: '𛈈'
CharacterDash1b209\u{1b209}: '𛈉'
CharacterDash1b20a\u{1b20a}: '𛈊'
CharacterDash1b20b\u{1b20b}: '𛈋'
CharacterDash1b20c\u{1b20c}: '𛈌'
CharacterDash1b20d\u{1b20d}: '𛈍'
CharacterDash1b20e\u{1b20e}: '𛈎'
CharacterDash1b20f\u{1b20f}: '𛈏'
CharacterDash1b210\u{1b210}: '𛈐'
CharacterDash1b211\u{1b211}: '𛈑'
CharacterDash1b212\u{1b212}: '𛈒'
CharacterDash1b213\u{1b213}: '𛈓'
CharacterDash1b214\u{1b214}: '𛈔'
CharacterDash1b215\u{1b215}: '𛈕'
CharacterDash1b216\u{1b216}: '𛈖'
CharacterDash1b217\u{1b217}: '𛈗'
CharacterDash1b218\u{1b218}: '𛈘'
CharacterDash1b219\u{1b219}: '𛈙'
CharacterDash1b21a\u{1b21a}: '𛈚'
CharacterDash1b21b\u{1b21b}: '𛈛'
CharacterDash1b21c\u{1b21c}: '𛈜'
CharacterDash1b21d\u{1b21d}: '𛈝'
CharacterDash1b21e\u{1b21e}: '𛈞'
CharacterDash1b21f\u{1b21f}: '𛈟'
CharacterDash1b220\u{1b220}: '𛈠'
CharacterDash1b221\u{1b221}: '𛈡'
CharacterDash1b222\u{1b222}: '𛈢'
CharacterDash1b223\u{1b223}: '𛈣'
CharacterDash1b224\u{1b224}: '𛈤'
CharacterDash1b225\u{1b225}: '𛈥'
CharacterDash1b226\u{1b226}: '𛈦'
CharacterDash1b227\u{1b227}: '𛈧'
CharacterDash1b228\u{1b228}: '𛈨'
CharacterDash1b229\u{1b229}: '𛈩'
CharacterDash1b22a\u{1b22a}: '𛈪'
CharacterDash1b22b\u{1b22b}: '𛈫'
CharacterDash1b22c\u{1b22c}: '𛈬'
CharacterDash1b22d\u{1b22d}: '𛈭'
CharacterDash1b22e\u{1b22e}: '𛈮'
CharacterDash1b22f\u{1b22f}: '𛈯'
CharacterDash1b230\u{1b230}: '𛈰'
CharacterDash1b231\u{1b231}: '𛈱'
CharacterDash1b232\u{1b232}: '𛈲'
CharacterDash1b233\u{1b233}: '𛈳'
CharacterDash1b234\u{1b234}: '𛈴'
CharacterDash1b235\u{1b235}: '𛈵'
CharacterDash1b236\u{1b236}: '𛈶'
CharacterDash1b237\u{1b237}: '𛈷'
CharacterDash1b238\u{1b238}: '𛈸'
CharacterDash1b239\u{1b239}: '𛈹'
CharacterDash1b23a\u{1b23a}: '𛈺'
CharacterDash1b23b\u{1b23b}: '𛈻'
CharacterDash1b23c\u{1b23c}: '𛈼'
CharacterDash1b23d\u{1b23d}: '𛈽'
CharacterDash1b23e\u{1b23e}: '𛈾'
CharacterDash1b23f\u{1b23f}: '𛈿'
CharacterDash1b240\u{1b240}: '𛉀'
CharacterDash1b241\u{1b241}: '𛉁'
CharacterDash1b242\u{1b242}: '𛉂'
CharacterDash1b243\u{1b243}: '𛉃'
CharacterDash1b244\u{1b244}: '𛉄'
CharacterDash1b245\u{1b245}: '𛉅'
CharacterDash1b246\u{1b246}: '𛉆'
CharacterDash1b247\u{1b247}: '𛉇'
CharacterDash1b248\u{1b248}: '𛉈'
CharacterDash1b249\u{1b249}: '𛉉'
CharacterDash1b24a\u{1b24a}: '𛉊'
CharacterDash1b24b\u{1b24b}: '𛉋'
CharacterDash1b24c\u{1b24c}: '𛉌'
CharacterDash1b24d\u{1b24d}: '𛉍'
CharacterDash1b24e\u{1b24e}: '𛉎'
CharacterDash1b24f\u{1b24f}: '𛉏'
CharacterDash1b250\u{1b250}: '𛉐'
CharacterDash1b251\u{1b251}: '𛉑'
CharacterDash1b252\u{1b252}: '𛉒'
CharacterDash1b253\u{1b253}: '𛉓'
CharacterDash1b254\u{1b254}: '𛉔'
CharacterDash1b255\u{1b255}: '𛉕'
CharacterDash1b256\u{1b256}: '𛉖'
CharacterDash1b257\u{1b257}: '𛉗'
CharacterDash1b258\u{1b258}: '𛉘'
CharacterDash1b259\u{1b259}: '𛉙'
CharacterDash1b25a\u{1b25a}: '𛉚'
CharacterDash1b25b\u{1b25b}: '𛉛'
CharacterDash1b25c\u{1b25c}: '𛉜'
CharacterDash1b25d\u{1b25d}: '𛉝'
CharacterDash1b25e\u{1b25e}: '𛉞'
CharacterDash1b25f\u{1b25f}: '𛉟'
CharacterDash1b260\u{1b260}: '𛉠'
CharacterDash1b261\u{1b261}: '𛉡'
CharacterDash1b262\u{1b262}: '𛉢'
CharacterDash1b263\u{1b263}: '𛉣'
CharacterDash1b264\u{1b264}: '𛉤'
CharacterDash1b265\u{1b265}: '𛉥'
CharacterDash1b266\u{1b266}: '𛉦'
CharacterDash1b267\u{1b267}: '𛉧'
CharacterDash1b268\u{1b268}: '𛉨'
CharacterDash1b269\u{1b269}: '𛉩'
CharacterDash1b26a\u{1b26a}: '𛉪'
CharacterDash1b26b\u{1b26b}: '𛉫'
CharacterDash1b26c\u{1b26c}: '𛉬'
CharacterDash1b26d\u{1b26d}: '𛉭'
CharacterDash1b26e\u{1b26e}: '𛉮'
CharacterDash1b26f\u{1b26f}: '𛉯'
CharacterDash1b270\u{1b270}: '𛉰'
CharacterDash1b271\u{1b271}: '𛉱'
CharacterDash1b272\u{1b272}: '𛉲'
CharacterDash1b273\u{1b273}: '𛉳'
CharacterDash1b274\u{1b274}: '𛉴'
CharacterDash1b275\u{1b275}: '𛉵'
CharacterDash1b276\u{1b276}: '𛉶'
CharacterDash1b277\u{1b277}: '𛉷'
CharacterDash1b278\u{1b278}: '𛉸'
CharacterDash1b279\u{1b279}: '𛉹'
CharacterDash1b27a\u{1b27a}: '𛉺'
CharacterDash1b27b\u{1b27b}: '𛉻'
CharacterDash1b27c\u{1b27c}: '𛉼'
CharacterDash1b27d\u{1b27d}: '𛉽'
CharacterDash1b27e\u{1b27e}: '𛉾'
CharacterDash1b27f\u{1b27f}: '𛉿'
CharacterDash1b280\u{1b280}: '𛊀'
CharacterDash1b281\u{1b281}: '𛊁'
CharacterDash1b282\u{1b282}: '𛊂'
CharacterDash1b283\u{1b283}: '𛊃'
CharacterDash1b284\u{1b284}: '𛊄'
CharacterDash1b285\u{1b285}: '𛊅'
CharacterDash1b286\u{1b286}: '𛊆'
CharacterDash1b287\u{1b287}: '𛊇'
CharacterDash1b288\u{1b288}: '𛊈'
CharacterDash1b289\u{1b289}: '𛊉'
CharacterDash1b28a\u{1b28a}: '𛊊'
CharacterDash1b28b\u{1b28b}: '𛊋'
CharacterDash1b28c\u{1b28c}: '𛊌'
CharacterDash1b28d\u{1b28d}: '𛊍'
CharacterDash1b28e\u{1b28e}: '𛊎'
CharacterDash1b28f\u{1b28f}: '𛊏'
CharacterDash1b290\u{1b290}: '𛊐'
CharacterDash1b291\u{1b291}: '𛊑'
CharacterDash1b292\u{1b292}: '𛊒'
CharacterDash1b293\u{1b293}: '𛊓'
CharacterDash1b294\u{1b294}: '𛊔'
CharacterDash1b295\u{1b295}: '𛊕'
CharacterDash1b296\u{1b296}: '𛊖'
CharacterDash1b297\u{1b297}: '𛊗'
CharacterDash1b298\u{1b298}: '𛊘'
CharacterDash1b299\u{1b299}: '𛊙'
CharacterDash1b29a\u{1b29a}: '𛊚'
CharacterDash1b29b\u{1b29b}: '𛊛'
CharacterDash1b29c\u{1b29c}: '𛊜'
CharacterDash1b29d\u{1b29d}: '𛊝'
CharacterDash1b29e\u{1b29e}: '𛊞'
CharacterDash1b29f\u{1b29f}: '𛊟'
CharacterDash1b2a0\u{1b2a0}: '𛊠'
CharacterDash1b2a1\u{1b2a1}: '𛊡'
CharacterDash1b2a2\u{1b2a2}: '𛊢'
CharacterDash1b2a3\u{1b2a3}: '𛊣'
CharacterDash1b2a4\u{1b2a4}: '𛊤'
CharacterDash1b2a5\u{1b2a5}: '𛊥'
CharacterDash1b2a6\u{1b2a6}: '𛊦'
CharacterDash1b2a7\u{1b2a7}: '𛊧'
CharacterDash1b2a8\u{1b2a8}: '𛊨'
CharacterDash1b2a9\u{1b2a9}: '𛊩'
CharacterDash1b2aa\u{1b2aa}: '𛊪'
CharacterDash1b2ab\u{1b2ab}: '𛊫'
CharacterDash1b2ac\u{1b2ac}: '𛊬'
CharacterDash1b2ad\u{1b2ad}: '𛊭'
CharacterDash1b2ae\u{1b2ae}: '𛊮'
CharacterDash1b2af\u{1b2af}: '𛊯'
CharacterDash1b2b0\u{1b2b0}: '𛊰'
CharacterDash1b2b1\u{1b2b1}: '𛊱'
CharacterDash1b2b2\u{1b2b2}: '𛊲'
CharacterDash1b2b3\u{1b2b3}: '𛊳'
CharacterDash1b2b4\u{1b2b4}: '𛊴'
CharacterDash1b2b5\u{1b2b5}: '𛊵'
CharacterDash1b2b6\u{1b2b6}: '𛊶'
CharacterDash1b2b7\u{1b2b7}: '𛊷'
CharacterDash1b2b8\u{1b2b8}: '𛊸'
CharacterDash1b2b9\u{1b2b9}: '𛊹'
CharacterDash1b2ba\u{1b2ba}: '𛊺'
CharacterDash1b2bb\u{1b2bb}: '𛊻'
CharacterDash1b2bc\u{1b2bc}: '𛊼'
CharacterDash1b2bd\u{1b2bd}: '𛊽'
CharacterDash1b2be\u{1b2be}: '𛊾'
CharacterDash1b2bf\u{1b2bf}: '𛊿'
CharacterDash1b2c0\u{1b2c0}: '𛋀'
CharacterDash1b2c1\u{1b2c1}: '𛋁'
CharacterDash1b2c2\u{1b2c2}: '𛋂'
CharacterDash1b2c3\u{1b2c3}: '𛋃'
CharacterDash1b2c4\u{1b2c4}: '𛋄'
CharacterDash1b2c5\u{1b2c5}: '𛋅'
CharacterDash1b2c6\u{1b2c6}: '𛋆'
CharacterDash1b2c7\u{1b2c7}: '𛋇'
CharacterDash1b2c8\u{1b2c8}: '𛋈'
CharacterDash1b2c9\u{1b2c9}: '𛋉'
CharacterDash1b2ca\u{1b2ca}: '𛋊'
CharacterDash1b2cb\u{1b2cb}: '𛋋'
CharacterDash1b2cc\u{1b2cc}: '𛋌'
CharacterDash1b2cd\u{1b2cd}: '𛋍'
CharacterDash1b2ce\u{1b2ce}: '𛋎'
CharacterDash1b2cf\u{1b2cf}: '𛋏'
CharacterDash1b2d0\u{1b2d0}: '𛋐'
CharacterDash1b2d1\u{1b2d1}: '𛋑'
CharacterDash1b2d2\u{1b2d2}: '𛋒'
CharacterDash1b2d3\u{1b2d3}: '𛋓'
CharacterDash1b2d4\u{1b2d4}: '𛋔'
CharacterDash1b2d5\u{1b2d5}: '𛋕'
CharacterDash1b2d6\u{1b2d6}: '𛋖'
CharacterDash1b2d7\u{1b2d7}: '𛋗'
CharacterDash1b2d8\u{1b2d8}: '𛋘'
CharacterDash1b2d9\u{1b2d9}: '𛋙'
CharacterDash1b2da\u{1b2da}: '𛋚'
CharacterDash1b2db\u{1b2db}: '𛋛'
CharacterDash1b2dc\u{1b2dc}: '𛋜'
CharacterDash1b2dd\u{1b2dd}: '𛋝'
CharacterDash1b2de\u{1b2de}: '𛋞'
CharacterDash1b2df\u{1b2df}: '𛋟'
CharacterDash1b2e0\u{1b2e0}: '𛋠'
CharacterDash1b2e1\u{1b2e1}: '𛋡'
CharacterDash1b2e2\u{1b2e2}: '𛋢'
CharacterDash1b2e3\u{1b2e3}: '𛋣'
CharacterDash1b2e4\u{1b2e4}: '𛋤'
CharacterDash1b2e5\u{1b2e5}: '𛋥'
CharacterDash1b2e6\u{1b2e6}: '𛋦'
CharacterDash1b2e7\u{1b2e7}: '𛋧'
CharacterDash1b2e8\u{1b2e8}: '𛋨'
CharacterDash1b2e9\u{1b2e9}: '𛋩'
CharacterDash1b2ea\u{1b2ea}: '𛋪'
CharacterDash1b2eb\u{1b2eb}: '𛋫'
CharacterDash1b2ec\u{1b2ec}: '𛋬'
CharacterDash1b2ed\u{1b2ed}: '𛋭'
CharacterDash1b2ee\u{1b2ee}: '𛋮'
CharacterDash1b2ef\u{1b2ef}: '𛋯'
CharacterDash1b2f0\u{1b2f0}: '𛋰'
CharacterDash1b2f1\u{1b2f1}: '𛋱'
CharacterDash1b2f2\u{1b2f2}: '𛋲'
CharacterDash1b2f3\u{1b2f3}: '𛋳'
CharacterDash1b2f4\u{1b2f4}: '𛋴'
CharacterDash1b2f5\u{1b2f5}: '𛋵'
CharacterDash1b2f6\u{1b2f6}: '𛋶'
CharacterDash1b2f7\u{1b2f7}: '𛋷'
CharacterDash1b2f8\u{1b2f8}: '𛋸'
CharacterDash1b2f9\u{1b2f9}: '𛋹'
CharacterDash1b2fa\u{1b2fa}: '𛋺'
CharacterDash1b2fb\u{1b2fb}: '𛋻'
Methods
impl Nushu[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case